import { IActor } from "./Actors";
import { BattleOutcome } from "./Animations";
import { IBattleInfo, IBattleOptions } from "./Battles";
import { IBattleMovr, IBattleMovrSettings } from "./IBattleMovr";
import { Team } from "./Teams";
/**
 * Drives RPG-like battles between two teams of actors.
 */
export declare class BattleMovr implements IBattleMovr {
    /**
     * Selector factories keyed by type name.
     */
    private readonly actionsOrderer;
    /**
     * Animations for various battle activities.
     */
    private readonly animations;
    /**
     * Selector factories keyed by type name.
     */
    private readonly selectorFactories;
    /**
     * Animator for the current battle, if one is happening.
     */
    private animator?;
    /**
     * Battle info for the current battle, if one is happening.
     */
    private battleInfo?;
    /**
     * Initializes a new instance of the BattleMovr class.
     *
     * @param settings   Settings to be used for initialization.
     */
    constructor(settings: IBattleMovrSettings);
    /**
     * Gets whether there is a current battle.
     *
     * @returns Whether there is a current battle.
     */
    inBattle(): boolean;
    /**
     * Gets battle info for the current battle.
     *
     * @returns Battle info for the current battle.
     */
    getBattleInfo(): IBattleInfo;
    /**
     * Starts a new battle.
     *
     * @param options   Options to start the battle.
     * @returns Battle info for the new battle.
     */
    startBattle(options: IBattleOptions): IBattleInfo;
    /**
     * Switches the selected actor for a team.
     *
     * @param team   Team switching actors.
     * @param newActor   New selected actor for the team.
     */
    switchSelectedActor(team: Team, newActor: IActor): void;
    /**
     * Stops the current battle.
     *
     * @param outcome   Why the battle stopped.
     * @param onComplete   Callback for when this is over.
     */
    stopBattle(outcome: BattleOutcome, onComplete?: () => void): void;
    /**
     * Creates a battle team from starting info.
     *
     * @param team   Starting info on a team.
     * @returns A battle team for the starting info.
     */
    private createTeamFromInfo;
}
