var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
define(["require", "exports", "../Teams", "./Actions", "./Animator", "./Introductions", "./Queue"], function (require, exports, Teams_1, Actions_1, Animator_1, Introductions_1, Queue_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    /**
     * Root animator for a battle.
     */
    var Main = /** @class */ (function (_super) {
        __extends(Main, _super);
        /**
         * Initializes a new instance of the Animator class.
         *
         * @param settings   Settings to be used for initialization.
         * @param actionsOrderer   Battle info for the battle.
         */
        function Main(settings, actionsOrderer) {
            var _this = _super.call(this, settings) || this;
            /**
             * Animator for teams' actions.
             */
            _this.actions = new Actions_1.Actions(_this);
            /**
             * Animator for teams introducing themselves.
             */
            _this.introductions = new Introductions_1.Introductions(_this);
            _this.actionsOrderer = actionsOrderer;
            return _this;
        }
        /**
         * Starts the battle's gameplay.
         */
        Main.prototype.run = function () {
            var _this = this;
            var queue = new Queue_1.Queue();
            queue.add(function (next) {
                _this.animations.start(next);
            });
            queue.add(function (next) {
                _this.introductions.run(next);
            });
            queue.run(function () {
                _this.waitForActions();
            });
        };
        /**
         * Waits for actions from each team's selector.
         */
        Main.prototype.waitForActions = function () {
            var _this = this;
            var actions = {};
            var completed = 0;
            var onChoice = function () {
                completed += 1;
                if (completed === 2) {
                    _this.executeActions(actions);
                }
            };
            this.battleInfo.teams.opponent.selector.nextAction(this.battleInfo, Teams_1.Team.opponent, function (action) {
                actions[Teams_1.Team[Teams_1.Team.opponent]] = action;
                onChoice();
            });
            this.battleInfo.teams.player.selector.nextAction(this.battleInfo, Teams_1.Team.player, function (action) {
                actions[Teams_1.Team[Teams_1.Team.player]] = action;
                onChoice();
            });
        };
        /**
         * Executes each team's chosen actions.
         *
         * @param actions   Chosen actions by the teams.
         */
        Main.prototype.executeActions = function (actions) {
            var _this = this;
            var queue = new Queue_1.Queue();
            var _loop_1 = function (action) {
                queue.add(function (next) {
                    _this.actions.run(action, next);
                });
            };
            for (var _i = 0, _a = this.actionsOrderer(actions); _i < _a.length; _i++) {
                var action = _a[_i];
                _loop_1(action);
            }
            queue.run(function () {
                _this.waitForActions();
            });
        };
        return Main;
    }(Animator_1.Animator));
    exports.Main = Main;
});
