/**
 * A callback that may be run in a queue.
 *
 * @param next   Handler for when it's done.
 */
export declare type IQueueCallback = (next: () => void) => void;
/**
 * Queues callbacks to be run.
 */
export declare class Queue {
    /**
     * Callbacks waiting to be run.
     */
    private readonly queuedCallbacks;
    /**
     * Queues an callback, if it exists.
     *
     * @param callback   A callback that may or may not exist.
     */
    add(callback?: IQueueCallback): void;
    /**
     * Runs the queued animations.
     *
     * @param onComplete   Handler for when animations are done.
     */
    run(onComplete: () => void): void;
    /**
     * Removes any pending queued callbacks.
     */
    clear(): void;
}
