define(["require", "exports"], function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    /**
     * Queues callbacks to be run.
     */
    var Queue = /** @class */ (function () {
        function Queue() {
            /**
             * Callbacks waiting to be run.
             */
            this.queuedCallbacks = [];
        }
        /**
         * Queues an callback, if it exists.
         *
         * @param callback   A callback that may or may not exist.
         */
        Queue.prototype.add = function (callback) {
            if (callback !== undefined) {
                this.queuedCallbacks.push(callback);
            }
        };
        /**
         * Runs the queued animations.
         *
         * @param onComplete   Handler for when animations are done.
         */
        Queue.prototype.run = function (onComplete) {
            var _this = this;
            var callback = this.queuedCallbacks.shift();
            if (callback !== undefined) {
                callback(function () {
                    _this.run(onComplete);
                });
            }
            else {
                onComplete();
            }
        };
        /**
         * Removes any pending queued callbacks.
         */
        Queue.prototype.clear = function () {
            this.queuedCallbacks.length = 0;
        };
        return Queue;
    }());
    exports.Queue = Queue;
});
